@@ -3,7 +3,7 @@ import FormLabel from '../../components/style/form-label'
 
 export default function PropertyReadOnly({value, onUpdate, configs}) {
   return (
-    <div style={{marginBottom: "3px"}}>
+    <div className="PropertyReadOnly" style={{marginBottom: "3px"}}>
       <div style={{display: "inline-block", width: "30%"}}>
         <FormLabel>{configs.label}</FormLabel>
       </div>
