@@ -15,7 +15,7 @@ export default function Sidebar({state, width, height}) {
 
   return (
     <aside
-      style={{minWidth: width, maxWidth: width, maxHeight: height, ...STYLE}}
+      style={{width, width, height, ...STYLE}}
       onKeyDown={event => event.stopPropagation()}
       onKeyUp={event => event.stopPropagation()}
       className="sidebar"
