@@ -3,12 +3,12 @@ import Button from './button';
 
 const STYLE = {
   borderColor: "#adadad",
-  backgroundColor: "#e6e6e6",
+  backgroundColor: "#e6e6e6"
 };
 
 const STYLE_HOVER = {
   backgroundColor: "#d4d4d4",
-  borderColor: "#8c8c8c",
+  borderColor: "#8c8c8c"
 };
 
 export default function CancelButton({children, ...rest}) {
