@@ -2,18 +2,17 @@ import React, {PropTypes, Component} from 'react';
 import Button from './button';
 
 const STYLE = {
-  borderColor: "#000",
+  borderColor: "#415375",
   backgroundColor: "#415375",
-  color: "#fff",
+  color: "#fff"
 };
 
 const STYLE_HOVER = {
-  borderColor: "#000",
+  borderColor: "#1f3149",
   backgroundColor: "#1f3149",
-  color: "#fff",
+  color: "#fff"
 };
 
 export default function FormSubmitButton({children, ...rest}) {
   return <Button type="submit" style={STYLE} styleHover={STYLE_HOVER} {...rest}>{children}</Button>
 }
-
