@@ -24,6 +24,9 @@ export default function appReducer(state, action) {
     case constants.SELECT_TOOL_EDIT:
     case constants.UNSELECT_ALL:
     case constants.SET_PROPERTIES:
+    case constants.SET_ITEMS_ATTRIBUTES:
+    case constants.SET_LINES_ATTRIBUTES:
+    case constants.SET_HOLES_ATTRIBUTES:
     case constants.REMOVE:
     case constants.UNDO:
     case constants.ROLLBACK:
